@@ -8,6 +8,8 @@ from inspect import getattr_static, signature, _empty
 from sqlalchemy.sql import functions
 from sqlalchemy.sql import elements
 
+from .serializers import STOP_VALUE
+
 
 def _default(value):
     """_default in more readable form"""
@@ -105,7 +107,9 @@ def _foreign_keys(value):
     return None
 
 
-def _binary_expression(value):
+def _binary_expression(
+    value, to_camel_case, serial_field_relations, level_limits, bidirectional
+):
     """ _binary_expression
 
     it is probably a relationship
@@ -114,13 +118,32 @@ def _binary_expression(value):
             is access to related column
     """
     if hasattr(value, "prop"):
-        return {
-            "readOnly": True,
-            "relationship": {
-                "type": "list" if value.prop.uselist else "single",
-                "entity": value.prop.entity.class_._class(),
-            },
-        }
+        rel_cls = value.prop.entity.class_
+        if serial_field_relations is not None:
+            serial_fields = serial_field_relations.get(rel_cls._class())
+        else:
+            serial_fields = None
+        level_limits.add(value._parententity.class_._class())
+        rel_fields = rel_cls.db.doc_table(
+            rel_cls, to_camel_case, serial_fields, level_limits=level_limits
+        )
+
+        if rel_fields != STOP_VALUE:
+            # extract just the fields
+            rel_fields = rel_fields[rel_cls._class()]["properties"]
+
+            read_only = not bidirectional
+
+            return {
+                "readOnly": read_only,
+                "relationship": {
+                    "type": "list" if value.prop.uselist else "single",
+                    "entity": rel_cls._class(),
+                    "fields": rel_fields,
+                },
+            }
+        else:
+            return None
 
     # here for thoroughness for now
     return {"readOnly": True, "unknown": str(value.expression)}
